@@ -5,6 +5,13 @@ from hsmodels.utils import to_coverage_dict
 def parse_spatial_reference(cls, value):
     if not value:
         return value
+    # This is a workaround for form submissions that do not include type
+    if isinstance(value, dict) and "type" not in value:
+        if "north" in value or "east" in value:
+            # it's a type point
+            value["type"] = "point"
+        else:
+            value["type"] = "box"
     if value['type'] == enums.SpatialReferenceType.box:
         return fields.BoxSpatialReference(**to_coverage_dict(value['value']))
     if value['type'] == enums.SpatialReferenceType.point:
@@ -45,6 +52,23 @@ def parse_spatial_coverage(cls, value):
     return value
 
 
+def normalize_additional_metadata(cls, value):
+    if isinstance(value, list):
+        as_dict = {}
+        for val in value:
+            if not isinstance(val, dict):
+                raise ValueError(f"List entry {val} must be a dict")
+            if "key" not in val:
+                raise ValueError(f"Missing the 'key' key in {val}")
+            if "value" not in val:
+                raise ValueError(f"Missing the 'value' key in {val}")
+            if val["key"] in as_dict:
+                raise ValueError(f"Found a duplicate key {val['key']}")
+            as_dict[val["key"]] = val["value"]
+        return as_dict
+    return value
+
+
 def list_not_empty(cls, l):
     if len(l) == 0:
         raise ValueError("list must contain at least one entry")
